{
    "$graph": [
        {
            "class": "CommandLineTool",
            "id": "#clean_vcf.cwl",
            "label": "clean-vcf",
            "doc": "This tool will clean a VCF for use in the OxoG workflow.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#clean_vcf.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "baseCommand": "/opt/oxog_scripts/clean_vcf.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            },
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.cleaned.vcf"
                    },
                    "id": "#clean_vcf.cwl/clean-vcf/clean_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#extract_snv.cwl",
            "label": "extract_snvs",
            "doc": "This tool will extract SNVs from INDEL VCFs\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#extract_snv.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*.extracted-SNVs.vcf.gz"
                    },
                    "id": "#extract_snv.cwl/extract_snvs/extracted_snvs"
                }
            ],
            "baseCommand": "/opt/oxog_scripts/extract_snvs_from_indels.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#normalize.cwl",
            "label": "normalize",
            "doc": "This tool will normalize an INDEL VCF using bcf-tools norm.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                }
            ],
            "inputs": [
                {
                    "id": "#normalize.cwl/vcf",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#normalize.cwl/ref",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".fai"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#normalize.cwl/normalized-vcf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.normalized.vcf.gz"
                    }
                }
            ],
            "baseCommand": "/opt/oxog_scripts/normalize.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#pass-filter.cwl",
            "label": "pass-filter",
            "doc": "This tool will pass-filter a VCF.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#pass-filter.cwl/vcfdir",
                    "type": "Directory",
                    "doc": "The directory containing the files"
                },
                {
                    "id": "#pass-filter.cwl/filesToFilter",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "doc": "The names of the files that will actually be filtered"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.pass-filtered.vcf.gz"
                    },
                    "id": "#pass-filter.cwl/pass-filter/output"
                }
            ],
            "arguments": [
                "$(inputs.vcfdir.path)",
                "$(inputs.filesToFilter)"
            ],
            "baseCommand": "/opt/oxog_scripts/pass_filter.sh",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "Workflow",
            "doc": "This workflow will perform preprocessing steps on VCFs for the OxoG/Variantbam/Annotation workflow.\n",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "name": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                            "type": "record",
                            "fields": [
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/mergedVcfs",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/normalizedVcfs",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/extractedSnvs",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                },
                                {
                                    "name": "#PreprocessedFilesType.yaml/PreprocessedFileset/cleanedVcfs",
                                    "type": {
                                        "type": "array",
                                        "items": "File"
                                    }
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "\nfunction filterForIndels(inArr)\n{\n\tvar arr = [];\n\tfor (var i = 0; i < inArr.length ; i++)\n\t{\n\t\tif (inArr[i].basename.indexOf(\"indel\") >= 0)\n\t\t{\n\t\t\tarr.push(inArr[i]);\n\t\t}\n\t}\n\treturn arr;\n}\n\n/**\n * workflowName - the name of the workflow to filter for.\n * vcfType - the type of VCF (snv, indel, etc...)\n * inArr - an array of files (File[]) to search through.\n */\nfunction filterFor(workflowName, vcfType, inArr)\n{\n\tvar arr = [];\n\tfor (var i = 0; i < inArr.length; i++)\n\t{\n\t\tif (typeof(inArr[i]) == \"string\") //(\"class\" in inArr[i] && inArr[i].class == \"File\")\n\t\t{\n\t\t\tif (inArr[i].indexOf(workflowName) >= 0 && inArr[i].indexOf(vcfType) >= 0)\n\t\t\t{\n\t\t\t\tarr.push(inArr[i])\n\t\t\t}\n\t\t}\n\t\telse\n\t\t{\n\t\t\tif (\"class\" in inArr[i] && inArr[i].class == \"File\")\n\t\t\t{\n\t\t\t\tif (inArr[i].basename.indexOf(workflowName) >= 0 && inArr[i].basename.indexOf(vcfType) >= 0)\n\t\t\t\t{\n\t\t\t\t\tarr.push(inArr[i])\n\t\t\t\t}\n\t\t\t}\n\t\t}\n\t}\n\treturn arr;\n}\n",
                        "\nfunction formatArray(arr)\n{\n\tvar files = \"\";\n\tfor (var i = 0; i < arr.length; i++)\n\t{\n\t\tfiles = files.concat(arr[i].path,\",\");\n\t}\n\treturn files;\n}\n"
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/vcfdir",
                    "type": "Directory",
                    "doc": "The directory where the files are"
                },
                {
                    "id": "#main/filesToPreprocess",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "doc": "The files to process"
                },
                {
                    "id": "#main/ref",
                    "type": "File",
                    "doc": "Reference file, used for normalized INDELs"
                },
                {
                    "id": "#main/out_dir",
                    "type": "string",
                    "doc": "The name of the output directory"
                }
            ],
            "outputs": [
                {
                    "type": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                    "outputSource": "#main/populate_output_record/output_record",
                    "id": "#main/preprocessedFiles"
                }
            ],
            "steps": [
                {
                    "doc": "Clean the VCFs.",
                    "run": "#clean_vcf.cwl",
                    "scatter": [
                        "#main/clean/vcf"
                    ],
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/clean/vcf"
                        }
                    ],
                    "out": [
                        "#main/clean/clean_vcf"
                    ],
                    "id": "#main/clean"
                },
                {
                    "doc": "Clean the MUSE VCFs.",
                    "run": "#clean_vcf.cwl",
                    "scatter": [
                        "#main/clean_muse/vcf"
                    ],
                    "in": [
                        {
                            "source": "#main/gather_muse_snvs_for_cleaning/snvs_for_cleaning",
                            "id": "#main/clean_muse/vcf"
                        }
                    ],
                    "out": [
                        "#main/clean_muse/clean_vcf"
                    ],
                    "id": "#main/clean_muse"
                },
                {
                    "doc": "Extract SNVs from normalized INDELs",
                    "run": "#extract_snv.cwl",
                    "scatter": "#main/extract_snv/vcf",
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/extract_snv/vcf"
                        }
                    ],
                    "out": [
                        "#main/extract_snv/extracted_snvs"
                    ],
                    "id": "#main/extract_snv"
                },
                {
                    "doc": "Filters the input list and selects the INDEL VCFs.",
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/filter_for_indel/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_for_indel/out_vcf"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/filter_for_indel/f5200f22-87c6-4f34-92c0-74e67a36e836/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/filter_for_indel/f5200f22-87c6-4f34-92c0-74e67a36e836/out_vcf"
                            }
                        ],
                        "expression": "$({ out_vcf: filterForIndels(inputs.in_vcf) })\n",
                        "id": "#main/filter_for_indel/f5200f22-87c6-4f34-92c0-74e67a36e836"
                    },
                    "id": "#main/filter_for_indel"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_broad_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_broad_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_indels/ed8420b8-026a-40ad-b644-53c61e286090/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_indels/ed8420b8-026a-40ad-b644-53c61e286090/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"broad-snowman\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_broad_indels/ed8420b8-026a-40ad-b644-53c61e286090"
                    },
                    "id": "#main/gather_broad_indels"
                },
                {
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/gather_broad_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_broad_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_broad_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_snvs/fc31224c-c36b-4482-bd4f-dbdcce0beeb0/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_snvs/fc31224c-c36b-4482-bd4f-dbdcce0beeb0/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_snvs/fc31224c-c36b-4482-bd4f-dbdcce0beeb0/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( (filterFor(\"broad-mutect\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"broad-mutect\",\"snv_mnv\",inputs.extracted_snvs)) )\n})\n",
                        "id": "#main/gather_broad_snvs/fc31224c-c36b-4482-bd4f-dbdcce0beeb0"
                    },
                    "id": "#main/gather_broad_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/gather_broad_svs/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/gather_broad_svs/svs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_svs/a7f40791-6f3c-4399-879c-4e92ecb8c533/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_broad_svs/a7f40791-6f3c-4399-879c-4e92ecb8c533/svs_for_merge"
                            }
                        ],
                        "expression": "$({ svs_for_merge: filterFor(\"broad-dRanger_snowman\",\".sv.\",inputs.in_vcf) })\n",
                        "id": "#main/gather_broad_svs/a7f40791-6f3c-4399-879c-4e92ecb8c533"
                    },
                    "id": "#main/gather_broad_svs"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_dkfz_embl_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_dkfz_embl_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_indels/536fd338-9349-43eb-a800-0d361d32adb1/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_indels/536fd338-9349-43eb-a800-0d361d32adb1/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"dkfz-indelCalling\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_dkfz_embl_indels/536fd338-9349-43eb-a800-0d361d32adb1"
                    },
                    "id": "#main/gather_dkfz_embl_indels"
                },
                {
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/gather_dkfz_embl_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_dkfz_embl_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_dkfz_embl_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_snvs/9b183437-e84a-4fc0-be33-9c5d777ea02a/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_snvs/9b183437-e84a-4fc0-be33-9c5d777ea02a/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_snvs/9b183437-e84a-4fc0-be33-9c5d777ea02a/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( (filterFor(\"dkfz-snvCalling\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"dkfz-snvCalling\",\"snv_mnv\",inputs.extracted_snvs)) )\n})\n",
                        "id": "#main/gather_dkfz_embl_snvs/9b183437-e84a-4fc0-be33-9c5d777ea02a"
                    },
                    "id": "#main/gather_dkfz_embl_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/gather_dkfz_embl_svs/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/gather_dkfz_embl_svs/svs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_svs/6cdee1b4-c8f3-4e6f-9ef9-825485b50944/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_dkfz_embl_svs/6cdee1b4-c8f3-4e6f-9ef9-825485b50944/svs_for_merge"
                            }
                        ],
                        "expression": "$({ svs_for_merge: filterFor(\"embl-delly\",\".sv.\",inputs.in_vcf) })\n",
                        "id": "#main/gather_dkfz_embl_svs/6cdee1b4-c8f3-4e6f-9ef9-825485b50944"
                    },
                    "id": "#main/gather_dkfz_embl_svs"
                },
                {
                    "in": [
                        {
                            "source": "#main/clean_muse/clean_vcf",
                            "id": "#main/gather_muse_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_muse_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_muse_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs/bf3cce16-d385-45a4-8035-47ad0f03cbe6/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs/bf3cce16-d385-45a4-8035-47ad0f03cbe6/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs/bf3cce16-d385-45a4-8035-47ad0f03cbe6/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( filterFor(\"MUSE\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"MUSE\",\"snv_mnv\",inputs.extracted_snvs))\n})\n",
                        "id": "#main/gather_muse_snvs/bf3cce16-d385-45a4-8035-47ad0f03cbe6"
                    },
                    "id": "#main/gather_muse_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/vcfdir",
                            "id": "#main/gather_muse_snvs_for_cleaning/vcfdir"
                        },
                        {
                            "source": "#main/filesToPreprocess",
                            "id": "#main/gather_muse_snvs_for_cleaning/vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_muse_snvs_for_cleaning/snvs_for_cleaning"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": "Directory",
                                "id": "#main/gather_muse_snvs_for_cleaning/865ed17d-a691-48d3-9a50-65154fdf13c4/vcfdir"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "string"
                                },
                                "id": "#main/gather_muse_snvs_for_cleaning/865ed17d-a691-48d3-9a50-65154fdf13c4/vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_muse_snvs_for_cleaning/865ed17d-a691-48d3-9a50-65154fdf13c4/snvs_for_cleaning"
                            }
                        ],
                        "expression": "$({\n    snvs_for_cleaning: (  filterFor(\"MUSE\",\"snv_mnv\", inputs.vcfs ).map(function(e) {\n        e = { \"class\":\"File\", \"location\":inputs.vcfdir.location+\"/\"+e }\n        return e;\n    } )  )\n})\n",
                        "id": "#main/gather_muse_snvs_for_cleaning/865ed17d-a691-48d3-9a50-65154fdf13c4"
                    },
                    "id": "#main/gather_muse_snvs_for_cleaning"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_sanger_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_sanger_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_indels/584fdf23-a721-49a8-b429-1995ce32fe98/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_indels/584fdf23-a721-49a8-b429-1995ce32fe98/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"svcp\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_sanger_indels/584fdf23-a721-49a8-b429-1995ce32fe98"
                    },
                    "id": "#main/gather_sanger_indels"
                },
                {
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/gather_sanger_snvs/clean_vcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/gather_sanger_snvs/extracted_snvs"
                        }
                    ],
                    "out": [
                        "#main/gather_sanger_snvs/snvs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_snvs/4a18d93a-1c9a-4efd-9401-96a1f3483c67/clean_vcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_snvs/4a18d93a-1c9a-4efd-9401-96a1f3483c67/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_snvs/4a18d93a-1c9a-4efd-9401-96a1f3483c67/snvs_for_merge"
                            }
                        ],
                        "expression": "$({\n    snvs_for_merge: ( (filterFor(\"svcp\",\"snv_mnv\",inputs.clean_vcfs)).concat(filterFor(\"svcp\",\"snv_mnv\",inputs.extracted_snvs)) )\n})\n",
                        "id": "#main/gather_sanger_snvs/4a18d93a-1c9a-4efd-9401-96a1f3483c67"
                    },
                    "id": "#main/gather_sanger_snvs"
                },
                {
                    "in": [
                        {
                            "source": "#main/pass_filter/output",
                            "id": "#main/gather_sanger_svs/in_vcf"
                        }
                    ],
                    "out": [
                        "#main/gather_sanger_svs/svs_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_svs/4c64a267-6048-483d-84c7-9b460ab4c0c7/in_vcf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_sanger_svs/4c64a267-6048-483d-84c7-9b460ab4c0c7/svs_for_merge"
                            }
                        ],
                        "expression": "$({ svs_for_merge: filterFor(\"svfix\",\".sv.\",inputs.in_vcf) })\n",
                        "id": "#main/gather_sanger_svs/4c64a267-6048-483d-84c7-9b460ab4c0c7"
                    },
                    "id": "#main/gather_sanger_svs"
                },
                {
                    "in": [
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/gather_smufin_indels/normalized_vcfs"
                        }
                    ],
                    "out": [
                        "#main/gather_smufin_indels/indels_for_merge"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_smufin_indels/7a0228c9-ada4-4135-a431-05b546761efb/normalized_vcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/gather_smufin_indels/7a0228c9-ada4-4135-a431-05b546761efb/indels_for_merge"
                            }
                        ],
                        "expression": "$({ indels_for_merge: filterFor(\"smufin\",\"indel\",inputs.normalized_vcfs) })\n",
                        "id": "#main/gather_smufin_indels/7a0228c9-ada4-4135-a431-05b546761efb"
                    },
                    "id": "#main/gather_smufin_indels"
                },
                {
                    "doc": "Perform VCF merge by type (SNV, SV, INDEL) across workflows.",
                    "run": "#vcf_merge.cwl",
                    "in": [
                        {
                            "source": "#main/gather_broad_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/broad_indel"
                        },
                        {
                            "source": "#main/gather_broad_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/broad_snv"
                        },
                        {
                            "source": "#main/gather_broad_svs/svs_for_merge",
                            "id": "#main/merge_vcfs/broad_sv"
                        },
                        {
                            "source": "#main/gather_dkfz_embl_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/de_indel"
                        },
                        {
                            "source": "#main/gather_dkfz_embl_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/de_snv"
                        },
                        {
                            "source": "#main/gather_dkfz_embl_svs/svs_for_merge",
                            "id": "#main/merge_vcfs/de_sv"
                        },
                        {
                            "source": "#main/gather_muse_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/muse_snv"
                        },
                        {
                            "source": "#main/out_dir",
                            "id": "#main/merge_vcfs/out_dir"
                        },
                        {
                            "source": "#main/gather_sanger_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/sanger_indel"
                        },
                        {
                            "source": "#main/gather_sanger_snvs/snvs_for_merge",
                            "id": "#main/merge_vcfs/sanger_snv"
                        },
                        {
                            "source": "#main/gather_sanger_svs/svs_for_merge",
                            "id": "#main/merge_vcfs/sanger_sv"
                        },
                        {
                            "source": "#main/gather_smufin_indels/indels_for_merge",
                            "id": "#main/merge_vcfs/smufin_indel"
                        }
                    ],
                    "out": [
                        "#main/merge_vcfs/output"
                    ],
                    "id": "#main/merge_vcfs"
                },
                {
                    "doc": "Normalize the INDEL VCFs.",
                    "run": "#normalize.cwl",
                    "scatter": "#main/normalize/vcf",
                    "in": [
                        {
                            "source": "#main/ref",
                            "id": "#main/normalize/ref"
                        },
                        {
                            "source": "#main/filter_for_indel/out_vcf",
                            "id": "#main/normalize/vcf"
                        }
                    ],
                    "out": [
                        "#main/normalize/normalized-vcf"
                    ],
                    "id": "#main/normalize"
                },
                {
                    "in": [
                        {
                            "source": "#main/extract_snv/extracted_snvs",
                            "id": "#main/null_filter_extracted_snvs/extracted_snvs"
                        },
                        {
                            "source": "#main/clean_muse/clean_vcf",
                            "id": "#main/null_filter_extracted_snvs/muse_files"
                        }
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": [
                                        "File",
                                        "null"
                                    ]
                                },
                                "id": "#main/null_filter_extracted_snvs/c665fc67-442c-4da9-bbb0-a5f159653bfc/extracted_snvs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/null_filter_extracted_snvs/c665fc67-442c-4da9-bbb0-a5f159653bfc/cleaned_extracted_snvs"
                            }
                        ],
                        "expression": "$(\n    { cleaned_extracted_snvs: inputs.extracted_snvs.filter(function(n){return n != null}) }\n)\n",
                        "id": "#main/null_filter_extracted_snvs/c665fc67-442c-4da9-bbb0-a5f159653bfc"
                    },
                    "out": [
                        "#main/null_filter_extracted_snvs/cleaned_extracted_snvs"
                    ],
                    "id": "#main/null_filter_extracted_snvs"
                },
                {
                    "doc": "Filter out non-PASS lines from the VCFs in filesToProcess.",
                    "in": [
                        {
                            "source": [
                                "#main/filesToPreprocess"
                            ],
                            "valueFrom": "${\n    var VCFs = []\n    for (var i in self)\n    {\n        if (self[i].toLowerCase().indexOf(\"muse\") == -1)\n        {\n            VCFs.push(self[i]);\n        }\n    }\n    return VCFs;\n}\n",
                            "id": "#main/pass_filter/filesToFilter"
                        },
                        {
                            "source": "#main/vcfdir",
                            "id": "#main/pass_filter/vcfdir"
                        }
                    ],
                    "run": "#pass-filter.cwl",
                    "out": [
                        "#main/pass_filter/output"
                    ],
                    "id": "#main/pass_filter"
                },
                {
                    "in": [
                        {
                            "source": "#main/clean/clean_vcf",
                            "id": "#main/populate_output_record/cleanedVcfs"
                        },
                        {
                            "source": "#main/null_filter_extracted_snvs/cleaned_extracted_snvs",
                            "id": "#main/populate_output_record/extractedSnvs"
                        },
                        {
                            "source": "#main/merge_vcfs/output",
                            "id": "#main/populate_output_record/mergedVcfs"
                        },
                        {
                            "source": "#main/normalize/normalized-vcf",
                            "id": "#main/populate_output_record/normalizedVcfs"
                        }
                    ],
                    "out": [
                        "#main/populate_output_record/output_record"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/populate_output_record/0b51f05e-b380-4136-bd20-436808a71f33/cleanedVcfs"
                            },
                            {
                                "type": [
                                    "null",
                                    {
                                        "type": "array",
                                        "items": "File"
                                    }
                                ],
                                "id": "#main/populate_output_record/0b51f05e-b380-4136-bd20-436808a71f33/extractedSnvs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/populate_output_record/0b51f05e-b380-4136-bd20-436808a71f33/mergedVcfs"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/populate_output_record/0b51f05e-b380-4136-bd20-436808a71f33/normalizedVcfs"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "#PreprocessedFilesType.yaml/PreprocessedFileset",
                                "id": "#main/populate_output_record/0b51f05e-b380-4136-bd20-436808a71f33/output_record"
                            }
                        ],
                        "expression": "$(\n    {output_record: {\n        \"cleanedVcfs\": inputs.cleanedVcfs,\n        \"mergedVcfs\": inputs.mergedVcfs,\n        \"extractedSnvs\": inputs.extractedSnvs,\n        \"normalizedVcfs\": inputs.normalizedVcfs\n    }}\n)\n",
                        "id": "#main/populate_output_record/0b51f05e-b380-4136-bd20-436808a71f33"
                    },
                    "id": "#main/populate_output_record"
                }
            ],
            "id": "#main",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        },
        {
            "class": "CommandLineTool",
            "id": "#vcf_merge.cwl",
            "label": "merge_vcfs",
            "doc": "This tool will merge VCFs by type (SV, SNV, INDEL). This CWL wrapper was written by Solomon Shorser.\nThe Perl script was originaly written by Brian O'Connor and maintained by Solomon Shorser.\n",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/pancancer/pcawg-oxog-tools"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "\nfunction formatArray(arr)\n{\n\tvar files = \"\";\n\tfor (var i = 0; i < arr.length; i++)\n\t{\n\t\tfiles = files.concat(arr[i].path,\",\");\n\t}\n\treturn files;\n}\n"
                    ]
                }
            ],
            "inputs": [
                {
                    "id": "#vcf_merge.cwl/broad_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/sanger_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/de_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/muse_snv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/broad_sv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/sanger_sv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/de_sv",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/broad_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/sanger_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/de_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/smufin_indel",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#vcf_merge.cwl/out_dir",
                    "type": "string",
                    "inputBinding": {
                        "position": 12,
                        "prefix": "--outdir"
                    }
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.clean.sorted.vcf.gz"
                    },
                    "id": "#vcf_merge.cwl/merge_vcfs/output"
                }
            ],
            "arguments": [
                {
                    "prefix": "--broad_snv",
                    "valueFrom": "$(formatArray(inputs.broad_snv))"
                },
                {
                    "prefix": "--sanger_snv",
                    "valueFrom": "$(formatArray(inputs.sanger_snv))"
                },
                {
                    "prefix": "--dkfz_embl_snv",
                    "valueFrom": "$(formatArray(inputs.de_snv))"
                },
                {
                    "prefix": "--muse_snv",
                    "valueFrom": "$(formatArray(inputs.muse_snv))"
                },
                {
                    "prefix": "--broad_sv",
                    "valueFrom": "$(formatArray(inputs.broad_sv))"
                },
                {
                    "prefix": "--sanger_sv",
                    "valueFrom": "$(formatArray(inputs.sanger_sv))"
                },
                {
                    "prefix": "--dkfz_embl_sv",
                    "valueFrom": "$(formatArray(inputs.de_sv))"
                },
                {
                    "prefix": "--broad_indel",
                    "valueFrom": "$(formatArray(inputs.broad_indel))"
                },
                {
                    "prefix": "--sanger_indel",
                    "valueFrom": "$(formatArray(inputs.sanger_indel))"
                },
                {
                    "prefix": "--dkfz_embl_indel",
                    "valueFrom": "$(formatArray(inputs.de_indel))"
                },
                {
                    "prefix": "--smufin_indel",
                    "valueFrom": "$(formatArray(inputs.smufin_indel))"
                }
            ],
            "baseCommand": "/opt/oxog_scripts/vcf_merge_by_type.pl",
            "http://purl.org/dc/terms/creator": {
                "foaf:name": "Solomon Shorser",
                "foaf:mbox": "solomon.shorser@oicr.on.ca"
            }
        }
    ],
    "cwlVersion": "v1.0"
}
